@@ -55,10 +55,12 @@ class OpenAPI:
         template_folder: str = OPENAPI_TEMPLATE_FOLDER,
         filename: str = OPENAPI_FILENAME,
         openapi_version: str = OPENAPI_VERSION,
-        openai_info: dict = OPENAPI_INFO,
+        openapi_info: dict = OPENAPI_INFO,
         ui: str = OPENAPI_UI,
         extra_props: dict = {},
     ) -> None:
+        if not endpoint.endswith("/"):
+            endpoint += "/"
         self.name: str = name
         self.mode: str = mode
         self.endpoint: str = endpoint
@@ -66,7 +68,7 @@ class OpenAPI:
         self.template_folder: str = template_folder
         self.filename: str = filename
         self.openapi_version: str = openapi_version
-        self.info: dict = openai_info
+        self.info: dict = openapi_info
         self.ui: str = ui
         self.extra_props: dict = extra_props
 
@@ -92,7 +94,7 @@ class OpenAPI:
         )
 
         # docs/openapi.json
-        @blueprint.route(f"{self.endpoint}/<filename>")
+        @blueprint.route(f"{self.endpoint}<filename>")
         def ___jsonfile___(filename: str):
             if filename == self.filename:
                 return jsonify(self.spec)
@@ -128,7 +130,9 @@ class OpenAPI:
         tags = {}
 
         for rule in self.app.url_map.iter_rules():
-            if str(rule).startswith(self.endpoint) or str(rule).startswith("/static"):
+            if str(rule).startswith(
+                (f"{self.url_prefix or ''}{self.endpoint}", "/static")
+            ):
                 continue
 
             func = self.app.view_functions[rule.endpoint]
@@ -155,7 +159,7 @@ class OpenAPI:
                 spec = {
                     "summary": summary or func.__name__.capitalize(),
                     "description": desc or "",
-                    "operationID": func.__name__ + "__" + method.lower(),
+                    "operationId": func.__name__ + "__" + method.lower(),
                     "tags": getattr(func, "tags", []),
                 }
 
@@ -207,7 +211,7 @@ class OpenAPI:
                     spec["responses"]["200"] = {"description": "Successful Response"}
 
                 if any(
-                    [hasattr(func, schema) for schema in ("query", "data", "response")]
+                    [hasattr(func, schema) for schema in ("query", "body", "response")]
                 ):
                     spec["responses"]["400"] = {
                         "description": "Validation Error",
